var Environment = (function() {
  var environment;

  function setEnv() {
    chrome.storage.local.get('environment', function(storage) {
      if (storage) environment = storage.environment;
    });
  }

  // Set now.
  setEnv();

  // Update when the storage has changed.
  chrome.storage.onChanged.addListener(setEnv);

  return {
    get: function() {
      return environment || Environment.PRODUCTION;
    },

    is: function(env) {
      if (!env) throw new Error('No environment passed to Environment.is()');
      return this.get() === env;
    },

    getAppUrl: function() {
      if (this.is(Environment.LOCAL)) return 'https://app-local.mixmax.com';
      else if (this.is(Environment.STAGING)) return 'https://app-staging.mixmax.com';
      else return 'https://app.mixmax.com';
    },

    getComposeUrl: function() {
      if (this.is(Environment.LOCAL)) return 'https://compose-local.mixmax.com';
      else if (this.is(Environment.STAGING)) return 'https://compose-staging.mixmax.com';
      else return 'https://compose.mixmax.com';
    },

    getGatewayUrl: function() {
      if (this.is(Environment.LOCAL)) return 'https://gateway-local.mixmax.com';
      else if (this.is(Environment.STAGING)) return 'https://gateway-staging.mixmax.com';
      else return 'https://gateway.mixmax.com';
    },


    KNOWN_EXTENSION_IDS: Object.freeze({
      ocpljaamllnldhepankaeljmeeeghnid: 'main',
      acopemiijaedckfmlemjdimcnphgbald: 'beta',
    }),

    getExtensionChannel: function() {
      return this.KNOWN_EXTENSION_IDS[chrome.runtime.id];
    }
  };
})();

Environment.PRODUCTION = 'production';

Environment.STAGING = 'staging';

Environment.LOCAL = 'local';
