
chrome.runtime.onMessage.addListener(function(request) {
  window.postMessage(
    {
      sender: '__MIXMAX_MESSAGING_EXTENSION',
      version: 1, 
      method: request.method,
      payload: request.payload,
    },
    '*'
  );
});

const EXTENSION_ORIGINS = [
  'https://www.linkedin.com',
  'https://mail.google.com',
  chrome.runtime.getURL('/').slice(0, -1),
];

const EXTENSION_ORIGIN_SUFFIXES = ['.mixmax.com', '.force.com', '.salesforce.com'];

window.addEventListener('message', (e) => {
  if (
    !EXTENSION_ORIGINS.includes(e.origin) &&
    !(
      e.origin.startsWith('https://') &&
      EXTENSION_ORIGIN_SUFFIXES.some((suffix) => e.origin.endsWith(suffix))
    )
  ) {
    return;
  }

  if (e.source !== window) return;

  const data = e.data;
  if (!data || data.sender !== '__MIXMAX_MESSAGING_SOURCE') return;

  if (data.method === 'ViewLoader' && window.location.origin === 'https://mail.google.com') {
    error.captureMessage('got ViewLoader message, but extension no longer supports that method', {
      extra: {
        data,
      },
    });
    return;
  }

  try {
    chrome.runtime.sendMessage({
      canonicalUrl: data.canonicalUrl,
      invocationId: data.invocationId,
      method: data.method,
      payload: data.payload,
    });
  } catch (err) {
    if (/Invocation.+doesn't match/i.test(err.message)) {
      window.location.reload();
    } else {
      error.captureException(err, {
        culprit: 'Could not message extension',
        extra: {
          method: data.method,
          payload: data.payload,
        },
      });
    }
  }
});
