let enabledTelephoneLinks = false;
const CALLING_REPORT_RUNTIME_ERROR = 0.1;

function setEnabled() {
  chrome.storage.local.get(null , function(storage) {
    let isMixmaxEnabled = false;
    let hasCallingEnabled = false;

    enabledTelephoneLinks = Object.keys(storage).some(function(key) {
      if (/^onboarded_(.+)_[a-z]+$/.test(key) && storage[key]) {
        isMixmaxEnabled = true;
      }

      if (/^hasCallingFeature_(.+)_[a-z]+$/.test(key) && storage[key]) {
        hasCallingEnabled = true;
      }

      return isMixmaxEnabled && hasCallingEnabled;
    });
  });
}

setEnabled();
chrome.storage.onChanged.addListener(setEnabled);

document.documentElement.addEventListener(
  'click',
  handleClickEventForCallTo,
  true 
);

function handleClickEventForCallTo(e) {
  if (!enabledTelephoneLinks) return;
  if (e.defaultPrevented) return;

  const link = e.target.closest('a[href^="tel:"]');
  if (!link) return;

  e.preventDefault();
  e.stopPropagation();
  e.stopImmediatePropagation();

  const href = link.href;

  try {
    chrome.runtime.sendMessage({
      method: 'callTo',
      payload: {
        href,
      },
    });
  } catch (err) {
    if (/Invocation.+doesn't match/i.test(err.message)) {
      window.location.reload();
    } else {
      if (Math.random() > CALLING_REPORT_RUNTIME_ERROR) return; 
      error.captureException(err, {
        culprit: 'Could not message extension',
        extra: {
          payload: {
            href,
          },
        },
      });
    }
  }
}

window.disableCallTo = () => {
  document.documentElement.removeEventListener('click', handleClickEventForCallTo, true);
};
